Address

Struct Address 

#[repr(transparent)]
pub struct Address(pub [u8; 20]);
An Ethereum public address.

Tuple Fields

0: [u8; 20]

Implementations

Source

impl Address

pub fn from_slice(slice: &[u8]) -> Address

Creates an address from a slice.

Panics

This method panics if the length of the slice is not 20 bytes.

Examples

Basic usage:

let buffer = (0..255).collect::<Vec<_>>();
assert_eq!(
    Address::from_slice(&buffer[0..20]),
    address!("0x000102030405060708090a0b0c0d0e0f10111213"),
);
pub fn from_ref(array: &[u8; 20]) -> &Address

Creates a reference to an address from a reference to a 20-byte array.

Examples

Basic usage:

let arrays = [[0; 20], [1; 20]];
for address in arrays.iter().map(Address::from_ref) {
    println!("{address}");
}
pub fn from_mut(array: &mut [u8; 20]) -> &mut Address

Creates a mutable reference to an address from a mutable reference to a 20-byte array.

pub fn from_str_checksum(s: &str) -> Result<Address, ParseAddressError>

Parses a checksummed Address from a string.

Examples

Basic usage:

assert!(Address::from_str_checksum("0xEeeeeEeeeEeEeeEeEeEeeEEEeeeeEeeeeeeeEEeE").is_ok());
assert!(Address::from_str_checksum("EeeeeEeeeEeEeeEeEeEeeEEEeeeeEeeeeeeeEEeE").is_ok());
assert!(Address::from_str_checksum("0xeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee").is_err());